@@ -27,7 +27,7 @@ from giza.config.base import ConfigurationBase
 class RuntimeStateConfig(ConfigurationBase):
     _option_registry = [ 'length', 'days_to_save', 'builder_to_delete',
                          'git_branch', 'git_sign_patch',
-                         'clean_generated', 'include_mask', 'push_targets' ]
+                         'clean_generated', 'include_mask', 'push_targets', 'dry_run' ]
 
     def __init__(self, obj=None):
         super(RuntimeStateConfig, self).__init__(obj)
